use tardis::basic::dto::TardisContext;
use tardis::db::reldb_client::TardisActiveModel;
use tardis::db::sea_orm;
use tardis::db::sea_orm::*;
use tardis::TardisFuns;

#[derive(Clone, Debug, PartialEq, DeriveEntityModel)]
#[sea_orm(table_name = "test_app")]
pub struct Model {
    #[sea_orm(primary_key, auto_increment = false)]
    pub id: String,
    pub name: String,
    pub tenant_id: String,
}

#[derive(Copy, Clone, Debug, EnumIter, DeriveRelation)]
pub enum Relation {
    #[sea_orm(belongs_to = "super::tenant::Entity", from = "Column::TenantId", to = "super::tenant::Column::Id")]
    Tenant,
}

impl Related<super::tenant::Entity> for super::app::Entity {
    fn to() -> RelationDef {
        Relation::Tenant.def()
    }
}

impl Related<super::account::Entity> for super::app::Entity {
    fn to() -> RelationDef {
        super::app_account_rel::Relation::Account.def()
    }

    fn via() -> Option<RelationDef> {
        Some(super::app_account_rel::Relation::App.def().rev())
    }
}

impl TardisActiveModel for ActiveModel {
    fn fill_ctx(&mut self, _: &TardisContext, is_insert: bool) {
        if is_insert {
            self.id = Set(TardisFuns::field.nanoid());
        }
    }
}

impl ActiveModelBehavior for ActiveModel {}
